@@ -1,13 +1,13 @@
 """A decorator for equality operators to check that the other object has equal instance
 attributes."""
 from functools import wraps
-from typing import Any, Callable, Dict
+from typing import Any, Dict
 
 from seligimus.python.classes.attributes import get_instance_attributes
+from seligimus.python.decorators.operators.equality.equality_operator import EqualityOperator
 
 
-def equal_instance_attributes(
-        equality_operator: Callable[[Any, Any], bool]) -> Callable[[Any, Any], bool]:
+def equal_instance_attributes(equality_operator: EqualityOperator) -> EqualityOperator:
     """Return an equality operator which first checks if the other object has equal instance
     attributes."""
     @wraps(equality_operator)
